/**
 * EasyBeans
 * Copyright (C) 2006 Bull S.A.S.
 * Contact: easybeans@ow2.org
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation; either
 * version 2.1 of the License, or any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307
 * USA
 *
 * --------------------------------------------------------------------------
 * $Id: BasicConfigurator.java 4389 2008-12-15 13:48:57Z alitokmen $
 * --------------------------------------------------------------------------
 */

package org.ow2.util.scan.api.configurator;

import java.util.HashMap;
import java.util.Map;
import java.util.Set;

import org.ow2.util.scan.api.IAnnotationVisitor;
import org.ow2.util.scan.api.metadata.structures.JAnnotation;

/**
 * Implements a generic getAnnotationVisitor method with map.
 * @author Gael Lalire
 */
public abstract class BasicConfigurator implements ICommonConfigurator {

    /**
     * map a annotation class name with a visitor.
     */
    private Map<String, IAnnotationVisitor> annotationVisitors;

    /**
     * Constructor.
     */
    public BasicConfigurator() {
        annotationVisitors = new HashMap<String, IAnnotationVisitor>();
    }

    /**
     * @return map where add visitor
     */
    protected Map<String, IAnnotationVisitor> getAnnotationVisitors() {
        return annotationVisitors;
    }

    /**
     * @param annotation signature of annotation
     * @return the visitor in the map or empty visitor
     */
    public IAnnotationVisitor getAnnotationVisitor(final JAnnotation annotation) {
        return annotationVisitors.get(annotation.getClassName());
    }

    /**
     * This one do nothing, you may override it.
     * @param referencedClasses you may fill this set with class referenced in current metadata
     */
    public void configurationComplete(final Set<String> referencedClasses) {
    }

}
