/**
 * OW2 Util
 * Copyright (C) 2008 Bull S.A.S.
 * Contact: easybeans@ow2.org
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation; either
 * version 2.1 of the License, or (at your option) any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA
 *
 * --------------------------------------------------------------------------
 * $Id: IClassMetadata.java 4389 2008-12-15 13:48:57Z alitokmen $
 * --------------------------------------------------------------------------
 */

package org.ow2.util.scan.api.metadata;

import java.io.Serializable;
import java.util.Collection;
import java.util.List;

import org.ow2.util.scan.api.metadata.structures.JClass;
import org.ow2.util.scan.api.metadata.structures.JField;
import org.ow2.util.scan.api.metadata.structures.JMethod;

/**
 * Interface of a class metadata.
 * @param <C> interface of a class metadata
 * @param <M> interface of a method metadata
 * @param <F> interface of a field metadata
 * @author Gael Lalire
 */
public interface IClassMetadata<
    C extends IClassMetadata<C, M, F>,
    M extends IMethodMetadata<C, M, F>,
    F extends IFieldMetadata<C, M, F>> extends Serializable {

    /**
     * add a method metadata.
     * @param methodAnnotationMetadata the method metadata
     */
    void addStandardMethodMetadata(final M methodAnnotationMetadata);

    /**
     * @param jMethod key of the map of methods annotations.
     * @return method annotation metadata of a given method.
     */
    M getStandardMethodMetadata(final JMethod jMethod);

    /**
     * @param methodName the name of the method to search
     * @return list of method annotation metadata for the given method name
     */
    List<M> searchStandardMethodMetadata(final String methodName);

    /**
     * @param fieldName the name of the field to search
     * @return list of field annotation metadata for the given field name
     */
    List<F> searchStandardFieldMetadata(final String fieldName);

    /**
     * Get collections of methods annotation metadata.
     * @return collections of methods annotation metadata.
     */
    Collection<M> getStandardMethodMetadataCollection();

    /**
     * Add field annotation metadata for a given Bean.
     * @param fieldAnnotationMetadata metadata of a field.
     */
    void addStandardFieldMetadata(final F fieldAnnotationMetadata);

    /**
     * @param jField key of the map of fields annotations.
     * @return field annotation metadata of a given method.
     */
    F getStandardFieldMetadata(final JField jField);

    /**
     * Get collections of fields annotation metadata.
     * @return collections of fields annotation metadata.
     */
    Collection<? extends F> getStandardFieldMetadataCollection();

    /**
     * @return class representation
     */
    JClass getJClass();

    /**
     * @param jClass jClass
     */
    void setJClass(final JClass jClass);

}
