/**
 * OW2 Util
 * Copyright (C) 2006 Bull S.A.S.
 * Contact: easybeans@ow2.org
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation; either
 * version 2.1 of the License, or (at your option) any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA
 *
 * --------------------------------------------------------------------------
 * $Id: JAnnotation.java 6167 2012-02-09 16:46:06Z sauthieg $
 * --------------------------------------------------------------------------
 */

package org.ow2.util.scan.api.metadata.structures;

import java.io.Serializable;

/**
 * Annotation on class, method or field.
 * @author Gael Lalire
 */
public final class JAnnotation implements Serializable {

    /**
     * Serial version UID.
     */
    private static final long serialVersionUID = -6370092510864544109L;

    /**
     * annotation name.
     */
    private String className;

    /**
     * visibility of annotation.
     */
    private boolean visible;

    /**
     * Constructor.
     * @param className the class name of annotation
     * @param visible visible
     */
    public JAnnotation(final String className, final boolean visible) {
        if (className == null) {
            throw new IllegalArgumentException("Class name argument of JAnnotation constructor can not be null");
        }
        this.className = className;
        this.visible = visible;
    }

    /**
     * @return visibility of annotation
     */
    public boolean isVisible() {
        return visible;
    }

    /**
     * @return name of annotation class
     */
    public String getClassName() {
        return className;
    }

    /**
     * @return name hashcode
     */
    @Override
    public int hashCode() {
        return className.hashCode();
    }

    /**
     * @param obj the object to compare
     * @return true if same annotation.
     */
    @Override
    public boolean equals(final Object obj) {
        if (obj == this) {
            return true;
        }
        if (!(obj instanceof JAnnotation)) {
            return false;
        } else {
            JAnnotation jAnnotation = (JAnnotation) obj;
            if (className.equals(jAnnotation.className) && visible == jAnnotation.visible) {
                return true;
            }
            return false;
        }
    }

}
